@@ -1,6 +1,7 @@
 import dataclasses
 import logging
 import urllib.parse
+from types import UnionType
 from typing import Any, Optional, Dict, Union
 
 from aiohttp import Payload
@@ -43,7 +44,7 @@ class Answer(Response):
         if status is None and hasattr(self, _FIXED_STATUS_CODE__NAME):
             status = getattr(self, _FIXED_STATUS_CODE__NAME)
 
-        status_code = status or self.get_class_content_type()
+        status_code = status or self.get_class_status_code() or 200
         content_type = content_type or self.get_class_content_type()
         content_type = content_type.value if isinstance(content_type, ContentType) else content_type
         super().__init__(body=payload, status=status_code, content_type=content_type, headers=headers, charset=charset)
@@ -103,7 +104,8 @@ class JsonableAnswer(Answer):
             payload = custom_dumps(error_msg)
             status = HttpStatusCode.InternalServerError
 
-        super().__init__(payload, status, None, headers, charset)
+        super().__init__(payload=payload, status=status, content_type=self.get_class_content_type(),
+                         headers=headers, charset=charset)
 
     def convert_payload(self, payload):
         if payload_type := self.get_class_payload_type():
@@ -128,8 +130,8 @@ class JsonableAnswer(Answer):
         if hasattr(cls, _FIXED_PAYLOAD_TYPE__NAME):
             return getattr(cls, _FIXED_PAYLOAD_TYPE__NAME)
 
-    def __class_getitem__(cls, modifier: Union[HttpStatusCode, ContentType, type, None]) -> type:
-        if isinstance(modifier, type):
+    def __class_getitem__(cls, modifier: Union[HttpStatusCode, ContentType, type, UnionType, None]) -> type:
+        if isinstance(modifier, type | UnionType):
             if cls.get_class_payload_type():
                 raise TypeError("Payload type already fixed")
             return create_type(_prepare_class_name([cls], modifier), [cls], {_FIXED_PAYLOAD_TYPE__NAME: modifier})
